# TESLA

## TESLA: Deciphering tumor ecosystems at super-resolution from spatial transcriptomics

### Jian Hu,*, Kyle Coleman, Edward B. Lee, Humam Kadara, Linghua Wang,*,  Mingyao Li,*

TESLA is a machine learning framework for multi-level tissue annotation with pixel-level resolution in ST. TESLA integrates histological information with gene expression to annotate heterogeneous immune and tumor cells directly on the histology image. TESLA further detects unique Tumor Microenvironment (TME) features such as tertiary lymphoid structures and differential transcriptome programs in the core or edge of a tumor, which represent a promising avenue for understanding the spatial architecture of the TME. Although we illustrated the applications in cancer, TESLA can also be applied to other diseases. 
For more info, please go to: 
https://github.com/jianhuupenn/TESLA